@@ -17,15 +17,8 @@ use std::time::Duration;
 
 // note that this list must be topologically sorted by dependencies
 const CRATES_TO_PUBLISH: &[&str] = &[
-    // peepmatic
-    "peepmatic-traits",
-    "peepmatic-macro",
-    "peepmatic-automata",
-    "peepmatic-test-operator",
-    "peepmatic-runtime",
-    "peepmatic",
-    "peepmatic-souper",
     // cranelift
+    "cranelift-isle",
     "cranelift-entity",
     "wasmtime-types",
     "cranelift-bforest",
@@ -460,7 +453,6 @@ fn verify(crates: &[Crate]) {
             .env("CARGO_TARGET_DIR", "./target");
         if krate.name == "witx"
             || krate.name.contains("wasi-nn")
-            || krate.name.contains("peepmatic")
         {
             cmd.arg("--no-verify");
         }
